pub struct NetworkNodeConfigBuilder {
keypair: Option<Option<Keypair>>,
bind_address: Option<Option<Multiaddr>>,
announce_addresses: Option<Vec<Multiaddr>>,
replication_factor: Option<Option<NonZero<usize>>>,
gossip_config: Option<GossipConfig>,
request_response_config: Option<RequestResponseConfig>,
to_connect_addrs: Option<HashSet<(PeerId, Multiaddr)>>,
republication_interval: Option<Option<Duration>>,
ttl: Option<Option<Duration>>,
dht_file_path: Option<Option<String>>,
auth_message: Option<Option<Vec<u8>>>,
dht_timeout: Option<Option<Duration>>,
}Expand description
Builder for NetworkNodeConfig.
Fields
keypair: Option<Option<Keypair>>bind_address: Option<Option<Multiaddr>>announce_addresses: Option<Vec<Multiaddr>>replication_factor: Option<Option<NonZero<usize>>>gossip_config: Option<GossipConfig>request_response_config: Option<RequestResponseConfig>to_connect_addrs: Option<HashSet<(PeerId, Multiaddr)>>republication_interval: Option<Option<Duration>>ttl: Option<Option<Duration>>dht_file_path: Option<Option<String>>auth_message: Option<Option<Vec<u8>>>dht_timeout: Option<Option<Duration>>Implementations
Sourceimpl NetworkNodeConfigBuilder
impl NetworkNodeConfigBuilder
Sourcepub fn keypair<VALUE>(&mut self, value: VALUE) -> &mut NetworkNodeConfigBuilderwhere
VALUE: Into<Keypair>,
pub fn keypair<VALUE>(&mut self, value: VALUE) -> &mut NetworkNodeConfigBuilderwhere
VALUE: Into<Keypair>,
The keypair for the node
Sourcepub fn bind_address(
&mut self,
value: Option<Multiaddr>,
) -> &mut NetworkNodeConfigBuilder
pub fn bind_address( &mut self, value: Option<Multiaddr>, ) -> &mut NetworkNodeConfigBuilder
The address to bind to
Sourcepub fn announce_addresses(
&mut self,
value: Vec<Multiaddr>,
) -> &mut NetworkNodeConfigBuilder
pub fn announce_addresses( &mut self, value: Vec<Multiaddr>, ) -> &mut NetworkNodeConfigBuilder
Addresses to announce as external addresses to peers.
Each is added via Swarm::add_external_address during node setup. Identify will publish
them, and Kademlia will record them in our self-routing-table entry. Required when the
node is behind NAT, K8s NodePort, Docker bridge, etc., where the bind address is not
reachable from peers.
Sourcepub fn replication_factor<VALUE>(
&mut self,
value: VALUE,
) -> &mut NetworkNodeConfigBuilder
pub fn replication_factor<VALUE>( &mut self, value: VALUE, ) -> &mut NetworkNodeConfigBuilder
Replication factor for entries in the DHT
Sourcepub fn gossip_config(
&mut self,
value: GossipConfig,
) -> &mut NetworkNodeConfigBuilder
pub fn gossip_config( &mut self, value: GossipConfig, ) -> &mut NetworkNodeConfigBuilder
Configuration for GossipSub
Sourcepub fn request_response_config(
&mut self,
value: RequestResponseConfig,
) -> &mut NetworkNodeConfigBuilder
pub fn request_response_config( &mut self, value: RequestResponseConfig, ) -> &mut NetworkNodeConfigBuilder
Configuration for RequestResponse
Sourcepub fn to_connect_addrs(
&mut self,
value: HashSet<(PeerId, Multiaddr)>,
) -> &mut NetworkNodeConfigBuilder
pub fn to_connect_addrs( &mut self, value: HashSet<(PeerId, Multiaddr)>, ) -> &mut NetworkNodeConfigBuilder
list of addresses to connect to at initialization
Sourcepub fn republication_interval(
&mut self,
value: Option<Duration>,
) -> &mut NetworkNodeConfigBuilder
pub fn republication_interval( &mut self, value: Option<Duration>, ) -> &mut NetworkNodeConfigBuilder
republication interval in DHT, must be much less than ttl
Sourcepub fn ttl(&mut self, value: Option<Duration>) -> &mut NetworkNodeConfigBuilder
pub fn ttl(&mut self, value: Option<Duration>) -> &mut NetworkNodeConfigBuilder
expiratiry for records in DHT
Sourcepub fn dht_file_path(
&mut self,
value: Option<String>,
) -> &mut NetworkNodeConfigBuilder
pub fn dht_file_path( &mut self, value: Option<String>, ) -> &mut NetworkNodeConfigBuilder
The path to the file to save the DHT to
Sourcepub fn auth_message(
&mut self,
value: Option<Vec<u8>>,
) -> &mut NetworkNodeConfigBuilder
pub fn auth_message( &mut self, value: Option<Vec<u8>>, ) -> &mut NetworkNodeConfigBuilder
The signed authentication message sent to the remote peer If not supplied we will not send an authentication message during the handshake
Sourcepub fn dht_timeout(
&mut self,
value: Option<Duration>,
) -> &mut NetworkNodeConfigBuilder
pub fn dht_timeout( &mut self, value: Option<Duration>, ) -> &mut NetworkNodeConfigBuilder
The timeout for DHT lookups.
Sourcepub fn build(&self) -> Result<NetworkNodeConfig, NetworkNodeConfigBuilderError>
pub fn build(&self) -> Result<NetworkNodeConfig, NetworkNodeConfigBuilderError>